@@ -1,18 +1,5 @@
-//@HEADER
-// ************************************************************************
-//
-//                        Kokkos v. 4.0
-//       Copyright (2022) National Technology & Engineering
-//               Solutions of Sandia, LLC (NTESS).
-//
-// Under the terms of Contract DE-NA0003525 with NTESS,
-// the U.S. Government retains certain rights in this software.
-//
-// Part of Kokkos, under the Apache License v2.0 with LLVM Exceptions.
-// See https://kokkos.org/LICENSE for license information.
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
-//
-//@HEADER
+// SPDX-FileCopyrightText: Copyright Contributors to the Kokkos project
 
 // Experimental unified task-data parallel manycore LDRD
 
@@ -31,17 +18,19 @@ static_assert(false,
 //----------------------------------------------------------------------------
 //----------------------------------------------------------------------------
 
+#ifdef KOKKOS_ENABLE_DEPRECATED_CODE_4
 namespace Kokkos {
 
 /// Trivial wrapper for raw pointers that express ownership.
 template <class T>
-using OwningRawPtr = T*;
+using OwningRawPtr KOKKOS_DEPRECATED = T*;
 
 /// Trivial wrapper for raw pointers that do not express ownership.
 template <class T>
-using ObservingRawPtr = T*;
+using ObservingRawPtr KOKKOS_DEPRECATED = T*;
 
 }  // end namespace Kokkos
+#endif
 
 //----------------------------------------------------------------------------
 //----------------------------------------------------------------------------
