@@ -1,18 +1,5 @@
-//@HEADER
-// ************************************************************************
-//
-//                        Kokkos v. 4.0
-//       Copyright (2022) National Technology & Engineering
-//               Solutions of Sandia, LLC (NTESS).
-//
-// Under the terms of Contract DE-NA0003525 with NTESS,
-// the U.S. Government retains certain rights in this software.
-//
-// Part of Kokkos, under the Apache License v2.0 with LLVM Exceptions.
-// See https://kokkos.org/LICENSE for license information.
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
-//
-//@HEADER
+// SPDX-FileCopyrightText: Copyright Contributors to the Kokkos project
 
 #ifndef KOKKOS_OPENACC_FUNCTOR_ADAPTER_HPP
 #define KOKKOS_OPENACC_FUNCTOR_ADAPTER_HPP
@@ -34,6 +21,7 @@ class FunctorAdapter;
     using WorkTag = typename Policy::work_tag;                     \
                                                                    \
    public:                                                         \
+    using functor_type = Functor;                                  \
     FunctorAdapter(Functor const &functor) : m_functor(functor) {} \
                                                                    \
     KOKKOS_IMPL_ACC_PRAGMA(routine CLAUSE)                         \
