@@ -575,16 +575,32 @@ class BasicView {
 #endif
 
  protected:
+  // Optimized subview constructor that calls submdspan_mapping directly
+  // and initializes members in the constructor body
   template <class OtherElementType, class OtherExtents, class OtherLayoutPolicy,
             class OtherAccessorPolicy, class... SliceSpecifiers>
   KOKKOS_INLINE_FUNCTION BasicView(
       Impl::SubViewCtorTag,
       const BasicView<OtherElementType, OtherExtents, OtherLayoutPolicy,
                       OtherAccessorPolicy> &src_view,
-      SliceSpecifiers... slices)
-      : BasicView(submdspan(
-            src_view.to_mdspan(),
-            Impl::transform_kokkos_slice_to_mdspan_slice(slices)...)) {
+      SliceSpecifiers... slices) {
+    // Avoid calling submdspan to not create temporary mdspan objects.
+    // Instead do what submdspan does: calling submdspan_mapping.
+    const auto sub_mapping_result = submdspan_mapping(
+        src_view.m_map,
+        Impl::transform_kokkos_slice_to_mdspan_slice(slices)...);
+
+    // Kokkos View precondition should happen in release build,
+    // and before any checks happen inside mdspan mapping ctor itself.
+    check_basic_view_constructibility(sub_mapping_result.mapping);
+
+    // Explicit cast is needed because submdspan_mapping may return a different
+    // layout type.
+    using sub_accessor_t = typename OtherAccessorPolicy::offset_policy;
+    m_ptr = src_view.m_acc.offset(src_view.m_ptr, sub_mapping_result.offset);
+    m_map = mapping_type(sub_mapping_result.mapping);
+    m_acc = sub_accessor_t(src_view.m_acc);
+
 #ifdef KOKKOS_ENABLE_DEBUG_BOUNDS_CHECK
     bool valid = subview_extents_valid(
         src_view, std::make_index_sequence<sizeof...(SliceSpecifiers)>{},
