@@ -1,18 +1,5 @@
-//@HEADER
-// ************************************************************************
-//
-//                        Kokkos v. 4.0
-//       Copyright (2022) National Technology & Engineering
-//               Solutions of Sandia, LLC (NTESS).
-//
-// Under the terms of Contract DE-NA0003525 with NTESS,
-// the U.S. Government retains certain rights in this software.
-//
-// Part of Kokkos, under the Apache License v2.0 with LLVM Exceptions.
-// See https://kokkos.org/LICENSE for license information.
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
-//
-//@HEADER
+// SPDX-FileCopyrightText: Copyright Contributors to the Kokkos project
 
 #ifndef KOKKOS_KOKKOS_TRAITS_FWD_HPP
 #define KOKKOS_KOKKOS_TRAITS_FWD_HPP
@@ -65,6 +52,7 @@ struct WorkItemPropertyTrait;
 struct LaunchBoundsTrait;
 struct OccupancyControlTrait;
 struct GraphKernelTrait;
+struct StaticBatchSizeTrait;
 struct WorkTagTrait;
 
 // Keep these sorted by frequency of use to reduce compilation time
@@ -80,6 +68,7 @@ using execution_policy_trait_specifications =
     LaunchBoundsTrait,
     OccupancyControlTrait,
     GraphKernelTrait,
+    StaticBatchSizeTrait,
     // This one has to be last, unfortunately:
     WorkTagTrait
   >;
