@@ -1,24 +1,16 @@
-//@HEADER
-// ************************************************************************
-//
-//                        Kokkos v. 4.0
-//       Copyright (2022) National Technology & Engineering
-//               Solutions of Sandia, LLC (NTESS).
-//
-// Under the terms of Contract DE-NA0003525 with NTESS,
-// the U.S. Government retains certain rights in this software.
-//
-// Part of Kokkos, under the Apache License v2.0 with LLVM Exceptions.
-// See https://kokkos.org/LICENSE for license information.
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
-//
-//@HEADER
+// SPDX-FileCopyrightText: Copyright Contributors to the Kokkos project
 
 #include <sstream>
 #include <iostream>
 #include <limits>
 
+#include <Kokkos_Macros.hpp>
+#ifdef KOKKOS_ENABLE_EXPERIMENTAL_CXX20_MODULES
+import kokkos.core;
+#else
 #include <Kokkos_Core.hpp>
+#endif
 
 namespace Test {
 
@@ -414,10 +406,15 @@ struct TestReduceCombinatoricalInstantiation {
 #endif
   }
 
+  // FIXME_CUDA segfaults at runtime when using a lambda
+  struct AddIndexToSum {
+    KOKKOS_FUNCTION
+    void operator()(const int i, double& lsum) const { lsum += i; }
+  };
+
   template <class... Args>
   static void AddLambdaRange(int N, void*, Args... args) {
-    AddReturnArgument(
-        N, args..., KOKKOS_LAMBDA(const int& i, double& lsum) { lsum += i; });
+    AddReturnArgument(N, args..., AddIndexToSum{});
   }
 
   template <class... Args>
@@ -492,27 +489,21 @@ struct TestReduceCombinatoricalInstantiation {
   template <class... Args>
   static void AddFunctorLambdaRange(int N, Args... args) {
     AddFunctor<0, Args...>(N, args...);
-#ifdef KOKKOS_ENABLE_CXX11_DISPATCH_LAMBDA
-    AddLambdaRange(
-        N,
-        std::conditional_t<
-            std::is_same<ExecSpace, Kokkos::DefaultExecutionSpace>::value,
-            void*, Kokkos::InvalidType>(),
-        args...);
-#endif
+    AddLambdaRange(N,
+                   std::conditional_t<
+                       std::is_same_v<ExecSpace, Kokkos::DefaultExecutionSpace>,
+                       void*, Kokkos::InvalidType>(),
+                   args...);
   }
 
   template <class... Args>
   static void AddFunctorLambdaTeam(int N, Args... args) {
     AddFunctor<1, Args...>(N, args...);
-#ifdef KOKKOS_ENABLE_CXX11_DISPATCH_LAMBDA
-    AddLambdaTeam(
-        N,
-        std::conditional_t<
-            std::is_same<ExecSpace, Kokkos::DefaultExecutionSpace>::value,
-            void*, Kokkos::InvalidType>(),
-        args...);
-#endif
+    AddLambdaTeam(N,
+                  std::conditional_t<
+                      std::is_same_v<ExecSpace, Kokkos::DefaultExecutionSpace>,
+                      void*, Kokkos::InvalidType>(),
+                  args...);
   }
 
   template <class... Args>
