@@ -1,23 +1,19 @@
-//@HEADER
-// ************************************************************************
-//
-//                        Kokkos v. 4.0
-//       Copyright (2022) National Technology & Engineering
-//               Solutions of Sandia, LLC (NTESS).
-//
-// Under the terms of Contract DE-NA0003525 with NTESS,
-// the U.S. Government retains certain rights in this software.
-//
-// Part of Kokkos, under the Apache License v2.0 with LLVM Exceptions.
-// See https://kokkos.org/LICENSE for license information.
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
-//
-//@HEADER
+// SPDX-FileCopyrightText: Copyright Contributors to the Kokkos project
 
 #ifndef KOKKOS_SIMD_TESTING_OPS_HPP
 #define KOKKOS_SIMD_TESTING_OPS_HPP
 
+#include <Kokkos_Macros.hpp>
+#ifdef KOKKOS_ENABLE_EXPERIMENTAL_CXX20_MODULES
+import kokkos.core;
+import kokkos.simd;
+#else
+#include <Kokkos_Core.hpp>
 #include <Kokkos_SIMD.hpp>
+#endif
+
+#include <cmath>
 
 class plus {
  public:
@@ -459,12 +455,10 @@ class masked_reduce_min {
   auto on_host_serial(T const& a, U, MaskType mask) const {
     if (Kokkos::Experimental::none_of(mask))
       return Kokkos::reduction_identity<U>::min();
-    auto w        = Kokkos::Experimental::where(mask, a);
-    auto const& v = w.impl_get_value();
-    auto const& m = w.impl_get_mask();
-    auto result   = Kokkos::reduction_identity<U>::min();
-    for (std::size_t i = 0; i < v.size(); ++i) {
-      if (m[i]) result = Kokkos::min(result, v[i]);
+
+    auto result = Kokkos::reduction_identity<U>::min();
+    for (std::size_t i = 0; i < T::size(); ++i) {
+      if (mask[i]) result = Kokkos::min(result, a[i]);
     }
     return result;
   }
@@ -478,12 +472,10 @@ class masked_reduce_min {
                                                MaskType mask) const {
     if (Kokkos::Experimental::none_of(mask))
       return Kokkos::reduction_identity<U>::min();
-    auto w        = Kokkos::Experimental::where(mask, a);
-    auto const& v = w.impl_get_value();
-    auto const& m = w.impl_get_mask();
-    auto result   = Kokkos::reduction_identity<U>::min();
-    for (std::size_t i = 0; i < v.size(); ++i) {
-      if (m[i]) result = Kokkos::min(result, v[i]);
+
+    auto result = Kokkos::reduction_identity<U>::min();
+    for (std::size_t i = 0; i < T::size(); ++i) {
+      if (mask[i]) result = Kokkos::min(result, a[i]);
     }
     return result;
   }
@@ -499,12 +491,10 @@ class masked_reduce_max {
   auto on_host_serial(T const& a, U, MaskType mask) const {
     if (Kokkos::Experimental::none_of(mask))
       return Kokkos::reduction_identity<U>::max();
-    auto w        = Kokkos::Experimental::where(mask, a);
-    auto const& v = w.impl_get_value();
-    auto const& m = w.impl_get_mask();
-    auto result   = Kokkos::reduction_identity<U>::max();
-    for (std::size_t i = 0; i < v.size(); ++i) {
-      if (m[i]) result = Kokkos::max(result, v[i]);
+
+    auto result = Kokkos::reduction_identity<U>::max();
+    for (std::size_t i = 0; i < T::size(); ++i) {
+      if (mask[i]) result = Kokkos::max(result, a[i]);
     }
     return result;
   }
@@ -518,12 +508,10 @@ class masked_reduce_max {
                                                MaskType mask) const {
     if (Kokkos::Experimental::none_of(mask))
       return Kokkos::reduction_identity<U>::max();
-    auto w        = Kokkos::Experimental::where(mask, a);
-    auto const& v = w.impl_get_value();
-    auto const& m = w.impl_get_mask();
-    auto result   = Kokkos::reduction_identity<U>::max();
-    for (std::size_t i = 0; i < v.size(); ++i) {
-      if (m[i]) result = Kokkos::max(result, v[i]);
+
+    auto result = Kokkos::reduction_identity<U>::max();
+    for (std::size_t i = 0; i < T::size(); ++i) {
+      if (mask[i]) result = Kokkos::max(result, a[i]);
     }
     return result;
   }
@@ -539,12 +527,10 @@ class masked_reduce {
   template <typename T, typename U, typename MaskType>
   auto on_host_serial(T const& a, U const& identity, MaskType mask) const {
     if (Kokkos::Experimental::none_of(mask)) return identity;
-    auto w        = Kokkos::Experimental::where(mask, a);
-    auto const& v = w.impl_get_value();
-    auto const& m = w.impl_get_mask();
-    U result      = identity;
-    for (std::size_t i = 0; i < v.size(); ++i) {
-      if (m[i]) result = BinaryOperation()(result, v[i]);
+
+    U result = Kokkos::Experimental::Impl::Identity<U, BinaryOperation>();
+    for (std::size_t i = 0; i < T::size(); ++i) {
+      if (mask[i]) result = BinaryOperation()(result, a[i]);
     }
     return result;
   }
@@ -558,23 +544,21 @@ class masked_reduce {
   KOKKOS_INLINE_FUNCTION auto on_device_serial(T const& a, U const& identity,
                                                MaskType mask) const {
     if (Kokkos::Experimental::none_of(mask)) return identity;
-    auto w        = Kokkos::Experimental::where(mask, a);
-    auto const& v = w.impl_get_value();
-    auto const& m = w.impl_get_mask();
-    U result      = identity;
-    for (std::size_t i = 0; i < v.size(); ++i) {
+
+    U result = Kokkos::Experimental::Impl::Identity<U, BinaryOperation>();
+    for (std::size_t i = 0; i < T::size(); ++i) {
       if constexpr (std::is_same_v<BinaryOperation, std::plus<>>) {
-        if (m[i]) result = result + v[i];
+        if (mask[i]) result = result + a[i];
       } else if constexpr (std::is_same_v<BinaryOperation, std::multiplies<>>) {
-        if (m[i]) result = result * v[i];
+        if (mask[i]) result = result * a[i];
       } else if constexpr (std::is_same_v<BinaryOperation, std::bit_and<>>) {
-        if (m[i]) result = result & v[i];
+        if (mask[i]) result = result & a[i];
       } else if constexpr (std::is_same_v<BinaryOperation, std::bit_or<>>) {
-        if (m[i]) result = result | v[i];
+        if (mask[i]) result = result | a[i];
       } else if constexpr (std::is_same_v<BinaryOperation, std::bit_xor<>>) {
-        if (m[i]) result = result ^ v[i];
+        if (mask[i]) result = result ^ a[i];
       } else {
-        if (m[i]) result = BinaryOperation()(result, v[i]);
+        if (mask[i]) result = BinaryOperation()(result, a[i]);
       }
     }
     return result;
